@@ -3,11 +3,12 @@ Created on 12 jan. 2013
 
 @author: sander
 '''
-from pylisp.utils.lcaf.base import LCAFAddress
-from pylisp.utils.lcaf import type_registry
+from bitstring import BitArray
+from pylisp.utils import make_prefix
 from pylisp.utils.afi import read_afi_address_from_bitstream, \
     get_bitstream_for_afi_address
-from bitstring import BitArray
+from pylisp.utils.lcaf import type_registry
+from pylisp.utils.lcaf.base import LCAFAddress
 
 
 class LCAFInstanceAddress(LCAFAddress):
@@ -22,9 +23,11 @@ class LCAFInstanceAddress(LCAFAddress):
         super(LCAFInstanceAddress, self).sanitize()
 
     @classmethod
-    def _from_data_bytes(cls, data):
+    def _from_data_bytes(cls, data, prefix_len=None):
         instance_id = data.read('uint:32')
         address = read_afi_address_from_bitstream(data)
+        if prefix_len is not None:
+            address = make_prefix(address, prefix_len)
         lcaf = cls(instance_id=instance_id,
                    address=address)
         lcaf.sanitize()
